==> elucidata-build-tools-1.0.1.tgz: package/lib/elucidata-build-tools/server.js <==
(function() {
  var build, css_response, express, inspect, js_response, options, puts, say, set_options, staticProvider, _, _ref;
  _ = require('underscore')._;
  _ref = require('sys'), puts = _ref.puts, inspect = _ref.inspect;
  build = require('./builder');
  express = require('express');
  staticProvider = require('connect/middleware/staticProvider');
  options = {
    quiet: false,
    port: 3000,
    js_uri: '/app.js',
    js_path: ['lib'],
    css_uri: '/app.css',
    css_path: ['styles']
  };
  say = function(msg) {
    if (!options.quiet) {
      return puts(msg);
    }
  };
  set_options = function(opts) {
    return options = _.extend(options, opts);
  };
  js_response = function(jsPaths) {
    return function(req, res, next) {
      return build.js(jsPaths, function(err, js) {
        if (err) {
          res.writeHead(500, {
            'Content-Type': 'text/plain'
          });
          res.send(err);
          puts("Server error:");
          puts(err);
          return puts("");
        } else {
          res.header('Content-Type', 'text/javascript');
          return res.send(js);
        }
      });
    };
  };
  css_response = function(cssPath) {
    return function(req, res, next) {
      return build.css(cssPaths, function(err, css) {
        if (err) {
          res.writeHead(500, {
            'Content-Type': 'text/plain'
          });
          res.send(err);
          puts("Server error:");
          puts(err);
          return puts("");
        } else {
          res.header('Content-Type', 'text/css');
          return res.send(css);
        }
      });
    };
  };
  _(exports).extend({
    createDevServer: function(opts) {
      var app;
      set_options(opts);
      app = express.createServer();
      app.use(staticProvider({
        root: options.root,
        cache: false,
        maxAge: 1
      }));
      if (options.js_uri) {
        app.get(options.js_uri, js_response(_([options.js_path]).flatten()));
      }
      if (options.css_uri) {
        app.get(options.css_uri, css_response(_([options.css_path]).flatten()));
      }
      return app;
    },
    jsResponder: js_response,
    cssResponder: css_response,
    setOptions: function(opts) {
      return set_options(opts);
    }
  });
}).call(this);

==> elucidata-build-tools-1.0.3.tgz: package/lib/elucidata-build-tools/server.js <==
(function() {
  var build, connect, css_response, express, inspect, js_response, options, puts, say, set_options, _, _ref;
  _ = require('underscore')._;
  _ref = require('sys'), puts = _ref.puts, inspect = _ref.inspect;
  build = require('./builder');
  express = require('express');
  connect = require('connect');
  options = {
    quiet: false,
    port: 3000,
    js_uri: '/app.js',
    js_path: ['lib'],
    css_uri: '/app.css',
    css_path: ['styles']
  };
  say = function(msg) {
    if (!options.quiet) {
      return puts(msg);
    }
  };
  set_options = function(opts) {
    return options = _.extend(options, opts);
  };
  js_response = function(jsPaths, opts) {
    return function(req, res, next) {
      return build.js(jsPaths, opts || {}, function(err, js) {
        if (err) {
          res.writeHead(500, {
            'Content-Type': 'text/plain'
          });
          res.send(err.message || err);
          puts("Server error:");
          puts(err.message || err);
          return puts("");
        } else {
          res.header('Content-Type', 'text/javascript');
          return res.send(js);
        }
      });
    };
  };
  css_response = function(cssPaths, opts) {
    var cssPath;
    cssPath = _(_([cssPaths]).flatten()).last();
    return function(req, res, next) {
      return build.css(cssPath, opts || {}, function(err, css) {
        if (err) {
          res.writeHead(500, {
            'Content-Type': 'text/plain'
          });
          res.send(err.message || err);
          puts("Server error:");
          puts(err.message || err);
          return puts("");
        } else {
          res.header('Content-Type', 'text/css');
          return res.send(css);
        }
      });
    };
  };
  _(exports).extend({
    createDevServer: function(opts) {
      var app;
      set_options(opts);
      app = express.createServer();
      app.get(options.js_uri, js_response(_([options.js_path]).flatten()));
      app.get(options.css_uri, css_response(_([options.css_path]).flatten()));
      app.use(connect.staticProvider({
        root: options.root,
        cache: false,
        maxAge: 1
      }));
      return app;
    },
    jsResponder: js_response,
    cssResponder: css_response,
    setOptions: function(opts) {
      return set_options(opts);
    }
  });
}).call(this);
